local ldb = LibStub:GetLibrary("LibDataBroker-1.1")

local L_GOLD = "g"
local L_SILVER = "s"
local L_COPPER = "c"

local L = GetLocale()
if L == "frFR" then
	L_GOLD = "o"
	L_SILVER = "a"
	L_COPPER = "c"
end
if L == "deDE" then
	L_GOLD = "g"
	L_SILVER = "s"
	L_COPPER = "k"
end

local Money = CreateFrame("frame")
LibStub("AceEvent-3.0"):Embed(Money)

Money.dataobj = LibStub:GetLibrary("LibDataBroker-1.1"):NewDataObject("Broker_Money", 
  { type = "data source", 
   label = "Broker Money", 
    icon = "Interface\\AddOns\\Broker_Money\\Icons\\UI-GoldIcon",
	text = "5",
   })
   
local options = {
	name = "Broker Money",
	type = "group",
	args = {
		confdesc = {
			order = 1,
			type = "description",
			name = "Simple money display for LDB\n",
			cmdHidden = true
		},
		showCoinIcons = {
			order = 2, 
			type = "toggle", 
			width = "full",
			name = "Show coin icons",
			desc = "Shows coin icons",
			get = function() return Broker_MoneyConfig.ShowCoinIcons end,
			set = function(_,v) Broker_MoneyConfig.ShowCoinIcons = v 
				Money:UpdateConfig()
			end,
		},
		showColoredText = {
			order = 3, 
			type = "toggle", 
			width = "full",
			name = "Show colored text",
			desc = "Shows colored text",
			get = function() return Broker_MoneyConfig.ShowColoredText end,
			set = function(_,v) Broker_MoneyConfig.ShowColoredText = v 
				Money:UpdateConfig()
			end,
		},				
		compressDisplay = {
			order = 4, 
			type = "toggle", 
			width = "full",
			name = "Compress display",
			desc = "Display only relevant information (Value not 0)",
			get = function() return Broker_MoneyConfig.CompressDisplay end,
			set = function(_,v) Broker_MoneyConfig.CompressDisplay = v 
				Money:UpdateConfig()
			end,
		},			
	}
}	
   
LibStub("AceConfig-3.0"):RegisterOptionsTable("Broker Money", options)
LibStub("AceConfigDialog-3.0"):AddToBlizOptions("Broker Money")

local currentMoney, tipshown
local goldicon, silvericon, coppericon
local COLOR_COPPER, COLOR_SILVER, COLOR_GOLD
local gold, silver, copper

local playerName = UnitName("player")

function Money:UpdateConfig() 
	if not Broker_MoneyConfig then 
		Broker_MoneyConfig = { 		
			ShowCoinIcons = true,
			ShowColoredText = true,
			CompressDisplay = false,
        }
  	end  	
	
	if not Broker_MoneyDB or not Broker_MoneyDB.chars then
		Broker_MoneyDB = {
			chars = {},
		}
	end
		
	if Broker_MoneyConfig.ShowCoinIcons then
		goldicon = " |TInterface\\AddOns\\Broker_Money\\Icons\\UI-GoldIcon::|t"
		silvericon = " |TInterface\\AddOns\\Broker_Money\\Icons\\UI-SilverIcon::|t"
		coppericon = " |TInterface\\AddOns\\Broker_Money\\Icons\\UI-CopperIcon::|t"
	else
		goldicon = string.format("|cffffd700%s|r", L_GOLD)
		silvericon = string.format("|cffc7c7cf%s|r", L_SILVER)
		coppericon = string.format("|cffeda55f%s|r", L_COPPER)
	end
	if Broker_MoneyConfig.ShowColoredText then
		COLOR_GOLD = "|cffffd700%i|r"
		COLOR_SILVER = "|cffc7c7cf%i|r"
		COLOR_COPPER = "|cffeda55f%i|r"		
	else 
		COLOR_COPPER = "%i"
		COLOR_SILVER = "%i"
		COLOR_GOLD = "%i"
	end
	
	Money:Update()
end

local function GetTipAnchor(frame)
	local x,y = frame:GetCenter()
	if not x or not y then return "TOPLEFT", "BOTTOMLEFT" end
	local hhalf = (x > UIParent:GetWidth()*2/3) and "RIGHT" or (x < UIParent:GetWidth()/3) and "LEFT" or ""
	local vhalf = (y > UIParent:GetHeight()/2) and "TOP" or "BOTTOM"
	return vhalf..hhalf, frame, (vhalf == "TOP" and "BOTTOM" or "TOP")..hhalf
end


function Money.dataobj.OnLeave()
	GameTooltip:Hide()
	tipshown = nil
end

function Money.dataobj.OnEnter(self)
	tipshown = self
 	GameTooltip:SetOwner(self, "ANCHOR_NONE")
	GameTooltip:SetPoint(GetTipAnchor(self))
	GameTooltip:ClearLines()

	GameTooltip:AddLine("Broker_Money")
	GameTooltip:AddLine(" ")
	
	local totalMoney = 0
	
	for name,value in pairs(Broker_MoneyDB.chars) do		
		GameTooltip:AddDoubleLine(string.format("%s: ", name), string.format("%s", Money:CreateMoneyString(value)), nil,nil,nil, 1,1,1)
		totalMoney = totalMoney + value
	end

	GameTooltip:AddLine(" ")
	
	GameTooltip:AddDoubleLine("Total: ", Money:CreateMoneyString(totalMoney), nil,nil,nil, 1,1,1)
	
	GameTooltip:Show()
end

function Money:CreateMoneyString(currentMoney) 
	gold = floor(currentMoney / 10000)
	silver = floor((currentMoney - (gold * 10000)) / 100)
	copper = mod(currentMoney, 100)
				
	moneystring = ""
	local CompressDisplay = Broker_MoneyConfig.CompressDisplay
	
	if(gold > 0 or not CompressDisplay) then
		moneystring = string.format("%s%s ",  string.format(COLOR_GOLD, gold), goldicon)
	end
	
	if((silver > 0 or gold > 0) or not CompressDisplay) then
		moneystring = moneystring..string.format("%s%s ", string.format(COLOR_SILVER, silver), silvericon)
	end
	
	moneystring = moneystring..string.format("%s%s", string.format(COLOR_COPPER, copper), coppericon)
	
	return moneystring
end

function Money:Update()
	local currentMoney = GetMoney()
	
	Broker_MoneyDB.chars[UnitName("player")] = currentMoney
	Money.dataobj.text = Money:CreateMoneyString(currentMoney)
	
	if tipshown then dataobj.OnEnter(tipshown) end
end

Money:RegisterEvent("PLAYER_MONEY", "Update")
Money:RegisterEvent("PLAYER_TRADE_MONEY", "Update")
Money:RegisterEvent("TRADE_MONEY_CHANGED", "Update")
Money:RegisterEvent("SEND_MAIL_MONEY_CHANGED", "Update")
Money:RegisterEvent("SEND_MAIL_COD_CHANGED", "Update")
Money:RegisterEvent("PLAYER_LOGIN", "UpdateConfig")

Money:UpdateConfig()